@@ -1,4 +1,4 @@
-#!/usr/bin/env python 
+#!/usr/pkg/bin/python3.7 
 '''
 dimension.py
 An Inkscape effect for adding CAD style dimensions to selected objects
@@ -29,13 +29,21 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 '''
 
-import sys, inkex, pathmodifier
+# standard library
+import sys
+try:
+    from subprocess import Popen, PIPE
+    bsubprocess = True
+except:
+    bsubprocess = False
+# local library
+import inkex
+import pathmodifier
 from simpletransform import *
-import gettext
-_ = gettext.gettext
+
 
 class Dimension(pathmodifier.PathModifier):
     def __init__(self):
@@ -48,6 +56,10 @@ class Dimension(pathmodifier.PathModifier):
                         action="store", type="float", 
                         dest="yoffset", default=100.0,
                         help="y offset of the horizontal dimension arrow")    
+        self.OptionParser.add_option("-t", "--type",
+                        action="store", type="string", 
+                        dest="type", default="geometric",
+                        help="Bounding box type")
 
     def addMarker(self, name, rotate):
         defs = self.xpathSingle('/svg:svg//svg:defs')
@@ -87,52 +99,76 @@ class Dimension(pathmodifier.PathModifier):
         return line
 
     def effect(self):
-        self.xoffset = self.options.xoffset
-        self.yoffset = self.options.yoffset
+        scale = self.unittouu('1px')    # convert to document units
+        self.xoffset = scale*self.options.xoffset
+        self.yoffset = scale*self.options.yoffset
 
-        self.bbox = computeBBox(self.selected.values())
+        # query inkscape about the bounding box
+        if len(self.options.ids) == 0:
+            inkex.errormsg(_("Please select an object."))
+            exit()
+        if self.options.type == "geometric":
+            self.bbox = computeBBox(self.selected.values())
+        else:
+            q = {'x':0,'y':0,'width':0,'height':0}
+            file = self.args[-1]
+            id = self.options.ids[0]
+            for query in q.keys():
+                if bsubprocess:
+                    p = Popen('inkscape --query-%s --query-id=%s "%s"' % (query,id,file), shell=True, stdout=PIPE, stderr=PIPE)
+                    rc = p.wait()
+                    q[query] = scale*float(p.stdout.read())
+                    err = p.stderr.read()
+                else:
+                    f,err = os.popen3('inkscape --query-%s --query-id=%s "%s"' % (query,id,file))[1:]
+                    q[query] = scale*float(f.read())
+                    f.close()
+                    err.close()
+            self.bbox = (q['x'], q['x']+q['width'], q['y'], q['y']+q['height'])
 
         # Avoid ugly failure on rects and texts.
         try:
             testing_the_water = self.bbox[0]
         except TypeError:
-            sys.exit(_('Unable to process this object.  Try changing it into a path first.'))
+            inkex.errormsg(_('Unable to process this object.  Try changing it into a path first.'))
+            exit()
 
         layer = self.current_layer
 
         self.addMarker('Arrow1Lstart', False)
         self.addMarker('Arrow1Lend',  True)
 
-        group = inkex.etree.Element("g")
+        group = inkex.etree.SubElement(layer, 'g')
+        # group = inkex.etree.Element("g")
         group.set('fill', 'none')
         group.set('stroke', 'black')
 
         line = self.dimHLine(self.bbox[2], [0, 1])
         line.set('marker-start', 'url(#Arrow1Lstart)')
         line.set('marker-end', 'url(#Arrow1Lend)')
-        line.set('stroke-width', '1')
+        line.set('stroke-width', str(scale))
         group.append(line)
 
         line = self.dimVLine(self.bbox[0], [0, 2])
-        line.set('stroke-width', '0.5')
+        line.set('stroke-width', str(0.5*scale))
         group.append(line)
         
         line = self.dimVLine(self.bbox[1], [0, 2])
-        line.set('stroke-width', '0.5')
+        line.set('stroke-width', str(0.5*scale))
         group.append(line)
         
         line = self.dimVLine(self.bbox[0], [1, 0])
         line.set('marker-start', 'url(#Arrow1Lstart)')
         line.set('marker-end', 'url(#Arrow1Lend)')
-        line.set('stroke-width', '1')
+        line.set('stroke-width', str(scale))
         group.append(line)
         
         line = self.dimHLine(self.bbox[2], [2, 0])
-        line.set('stroke-width', '0.5')
+        line.set('stroke-width', str(0.5*scale))
         group.append(line)
 
         line = self.dimHLine(self.bbox[3], [2, 0])
-        line.set('stroke-width', '0.5')
+        line.set('stroke-width', str(0.5*scale))
         group.append(line)
 
         for id, node in self.selected.iteritems():
@@ -145,4 +181,4 @@ if __name__ == '__main__':
     e.affect()
 
 
-# vim: expandtab shiftwidth=4 tabstop=8 softtabstop=4 encoding=utf-8 textwidth=99
+# vim: expandtab shiftwidth=4 tabstop=8 softtabstop=4 fileencoding=utf-8 textwidth=99
