@@ -14,12 +14,17 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 '''
+# standard library
+import base64
+import os
+import sys
+import urllib
+import urlparse
+# local library
+import inkex
 
-import inkex, os, base64, urlparse, urllib
-import gettext
-_ = gettext.gettext
 
 class Embedder(inkex.Effect):
     def __init__(self):
@@ -69,12 +74,15 @@ class Embedder(inkex.Effect):
                 if (absref != None):
                     path=absref
 
-            path=unicode(path, "utf-8")
-
+            try:
+                path=unicode(path, "utf-8")
+            except TypeError:
+                path=path
+                
             if (not os.path.isfile(path)):
                 inkex.errormsg(_('No xlink:href or sodipodi:absref attributes found, or they do not point to an existing file! Unable to embed image.'))
                 if path:
-                    inkex.errormsg(_("Sorry we could not locate %s") % path)
+                    inkex.errormsg(_("Sorry we could not locate %s") % str(path))
 
             if (os.path.isfile(path)):
                 file = open(path,"rb").read()
@@ -106,4 +114,4 @@ if __name__ == '__main__':
     e.affect()
 
 
-# vim: expandtab shiftwidth=4 tabstop=8 softtabstop=4 encoding=utf-8 textwidth=99
+# vim: expandtab shiftwidth=4 tabstop=8 softtabstop=4 fileencoding=utf-8 textwidth=99
