@@ -1373,6 +1373,18 @@ function slideUpdateExportLayer()
 	{
 		var nd = nodesToBeRemoved[ndCounter];
 
+		// Before removing the node, check whether it contains any definitions.
+		var defs = nd.getElementsByTagNameNS(NSS["svg"], "defs");
+
+		for (var defsCounter = 0; defsCounter < defs.length; defsCounter++)
+		{
+			if (defs[defsCounter].id)
+			{
+				newDoc.appendChild(defs[defsCounter].cloneNode(true));
+			}
+		}
+
+		// Remove node.
 		nd.parentNode.removeChild(nd);
 	}
 
@@ -1407,18 +1419,7 @@ function slideUpdateExportLayer()
 	}
 
 	// Serialise the new document.
-	var serializer = new XMLSerializer();
-	var strm = 
-	{
-		content : "",
-		close : function() {},  
-		flush : function() {},  
-		write : function(str, count) { this.content += str; }  
-	};
-
-	var xml = serializer.serializeToStream(newDoc, strm, 'UTF-8');
-
-	window.open('data:image/svg+xml;base64;charset=utf-8,' + window.btoa(strm.content), '_blank');
+  window.location = 'data:application/svg+xml;base64;charset=utf-8,' + window.btoa(unescape(encodeURIComponent((new XMLSerializer()).serializeToString(newDoc))));
 
 	// Unsuspend redraw.
 	ROOT_NODE.unsuspendRedraw(suspendHandle);
@@ -2720,3 +2721,7 @@ String.prototype.trim = function()
 	return this.replace(/^\s+|\s+$/g, '');
 }
 
+/** SVGElement.getTransformToElement polyfill */
+SVGElement.prototype.getTransformToElement = SVGElement.prototype.getTransformToElement || function(elem) {
+    return elem.getScreenCTM().inverse().multiply(this.getScreenCTM());
+};
