@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/pkg/bin/python3.7
 # Copyright 2008, 2009 Hannes Hochreiner
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@ sys.path.append('C:\Program Files\Inkscape\share\extensions')
 
 # We will use the inkex module with the predefined Effect base class.
 import inkex
-inkex.localize()
 
 class JessyInk_Effects(inkex.Effect):
 	def __init__(self):
