@@ -14,7 +14,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 barraud@math.univ-lille1.fr
 
 This code defines a basic class (PathModifier) of effects whose purpose is
@@ -39,8 +39,6 @@ import bezmisc
 import simplestyle
 from simpletransform import *
 
-inkex.localize()
-
 ####################################################################
 ##-- zOrder computation...
 ##-- this should be shipped out in a separate file. inkex.py?
